Learn R Programming

speaq (version 2.7.0)

GetWinedata.subset: Get subset of Winedata for code examples

Description

This functions extracts a small part of the Winedata to be used in code testing and code examples

Usage

GetWinedata.subset()

Arguments

Value

list of 2: spectra, ppm values, color and origin.

Examples

Run this code
# NOT RUN {
subset <- GetWinedata.subset()
subset.spectra = subset$Spectra
subset.ppm = subset$PPM.vector

# }

Run the code above in your browser using DataLab