Learn R Programming

speaq (version 2.7.0)

HMDBsearchR: Submit 1H NMR peaks to HMDB for compound search

Description

This function allows to search HMDB from within R by simply submitting the peaks you want to search for. The function will open a webpage with the query results or provide a link to the HMDB page with the results.

Usage

HMDBsearchR(peakVector, ppmTol = 0.02, returnURL = FALSE)

Arguments

peakVector

A vector with ppm values of peaks

ppmTol

The ppm tolerance for the HMDB search (default = 0.02).

returnURL

Return the URL instead of opening a webpage.

Value

Opens a webpage or returns a URL with the HMDB results

Examples

Run this code
# NOT RUN {
HMDBsearchR(peakVector = c(3.2, 3.38), ppmTol = 0.2, returnURL = TRUE)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab