Learn R Programming

speaq (version 1.2.2)

findRef: Reference finding

Description

This function is to heuristically detect a reference spectrum.

Usage

findRef(peakList)

Arguments

peakList
The peak lists of the spectra.

Value

Details

This function is to heuristically detect a reference spectrum, see the reference for more details.

References

Vu TN, Valkenborg D, Smets K, Verwaest KA, Dommisse R, Lemie`re F, Verschoren A, Goethals B, Laukens K. (2011) An integrated workflow for robust alignment and simplified quantitative analysis of NMR spectrometry data. BMC Bioinformatics. 2011 Oct 20;12:405.

Examples

Run this code

res=makeSimulatedData();
X=res$data;
groupLabel=res$label;


peakList <- detectSpecPeaks(X,
    nDivRange = c(128),                
    scales = seq(1, 16, 2),
    baselineThresh = 50000,
    SNR.Th = -1,
    verbose=FALSE
);


cat("\n Find the spectrum reference...")
resFindRef<- findRef(peakList);
refInd <- resFindRef$refInd;

cat("\n Order of spectrum for reference  \n");
for (i in 1:length(resFindRef$orderSpec))
    cat(paste(i, ":",resFindRef$orderSpec[i],sep=""), " ");
    
cat("\n The reference is: ", refInd);

Run the code above in your browser using DataLab