Learn R Programming

speaq (version 2.7.0)

findSegPeakList: Selecting the peaks in a segment

Description

This function is to find out which peaks belonging to a segment which ranges from startP to endP

Usage

findSegPeakList(peakList, startP, endP)

Arguments

peakList

The peak lists of the spectra.

startP

The starting point of the segment.

endP

The ending point of the segment.

Value

The list of indices of the peaks in the segment.

See Also

dohClusterCustommedSegments

Examples

Run this code
# NOT RUN {
res=makeSimulatedData();
X=res$data;
groupLabel=res$label;
peakList <- detectSpecPeaks(X,
                            nDivRange = c(128),
                            scales = seq(1, 16, 2),
                            baselineThresh = 50000,
                            SNR.Th = -1,
                            verbose=FALSE
                            );
cat("\n ", peakList[[1]])
segmentpeakList= findSegPeakList(peakList[[1]],400,600);
cat("\n ", segmentpeakList)     
                       
# }

Run the code above in your browser using DataLab