Learn R Programming

speaq (version 1.2.2)

returnLocalMaxima: Local maximum detection

Description

Find and return local maximum of a single spectrum.

Usage

returnLocalMaxima(spectrum)

Arguments

spectrum
A spectral sample in the vector format.

Value

Details

Find and return local maximum of a single spectrum.

Examples

Run this code

res=makeSimulatedData();
X=res$data;
groupLabel=res$label;


returnLocalMaxima(X[2,])	

Run the code above in your browser using DataLab