powered by
This functions extracts a small part of the Winedata to be used in code testing and code examples
GetWinedata.subset()
list of 2: spectra, ppm values, color and origin.
# NOT RUN { subset <- GetWinedata.subset() subset.spectra = subset$Spectra subset.ppm = subset$PPM.vector # }
Run the code above in your browser using DataLab